@@ -9,7 +9,6 @@
 
 package org.gnu.gtk;
 
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 
 /**
@@ -33,7 +32,7 @@ public class HButtonBox extends ButtonBox {
 	/**
 	 * Construct a new HButtonBox from a handle to a native resource.
 	 */
-	public HButtonBox(Handle handle) {
+	public HButtonBox(int handle) {
 	    super(handle);
 	}
 	
@@ -44,15 +43,13 @@ public class HButtonBox extends ButtonBox {
 		return new Type(gtk_hbutton_box_get_type());
 	}
 
-
+    /****************************************
+     * BEGINNING OF GENERATED CODE
+     ****************************************/
     native static final protected int gtk_hbutton_box_get_type ();
-    native static final protected Handle gtk_hbutton_box_new ();
-
-    /* Deprectated functions.
-    native static final private int gtk_hbutton_box_get_spacing_default();
-    native static final private int gtk_hbutton_box_get_layout_default();
-    native static final private void gtk_hbutton_box_set_spacing_default(int spacing);
-    native static final private void gtk_hbutton_box_set_layout_default(int layout);
-    */
+    native static final protected int gtk_hbutton_box_new ();
+    /****************************************
+     * END OF GENERATED CODE
+     ****************************************/
 }
 
